==> kubernetes-model-1.0.32-sources.jar: annotations/io/fabric8/kubernetes/api/model/StatusCauseFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;

public class StatusCauseFluentImpl<T extends StatusCauseFluent<T>> extends BaseFluent<T> implements StatusCauseFluent<T>{

     String field;     String message;     String reason;     Map<String, Object> additionalProperties = new HashMap();
public StatusCauseFluentImpl(){
    
}
public StatusCauseFluentImpl( StatusCause instance ){
    this.withField(instance.getField()); this.withMessage(instance.getMessage()); this.withReason(instance.getReason()); 
}

    public String getField(){
    return this.field;
    }
    public T withField( String field){
    this.field=field; return (T) this;
    }
    public String getMessage(){
    return this.message;
    }
    public T withMessage( String message){
    this.message=message; return (T) this;
    }
    public String getReason(){
    return this.reason;
    }
    public T withReason( String reason){
    this.reason=reason; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
StatusCauseFluentImpl that = (StatusCauseFluentImpl) o;
if (field != null ? !field.equals(that.field) :that.field != null) return false;
if (message != null ? !message.equals(that.message) :that.message != null) return false;
if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.50-sources.jar: annotations/io/fabric8/kubernetes/api/model/StatusCauseFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class StatusCauseFluentImpl<A extends StatusCauseFluent<A>> extends BaseFluent<A> implements StatusCauseFluent<A>{

     String field;     String message;     String reason;
public StatusCauseFluentImpl(){
    
}
public StatusCauseFluentImpl( StatusCause instance ){
    this.withField(instance.getField()); this.withMessage(instance.getMessage()); this.withReason(instance.getReason()); 
}

    public String getField(){
    return this.field;
    }
    public A withField( String field){
    this.field=field; return (A) this;
    }
    public String getMessage(){
    return this.message;
    }
    public A withMessage( String message){
    this.message=message; return (A) this;
    }
    public String getReason(){
    return this.reason;
    }
    public A withReason( String reason){
    this.reason=reason; return (A) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
StatusCauseFluentImpl that = (StatusCauseFluentImpl) o;
if (field != null ? !field.equals(that.field) :that.field != null) return false;
if (message != null ? !message.equals(that.message) :that.message != null) return false;
if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
return true;

    }



}
